@@ -280,7 +280,7 @@ static double lookup (double x, double *values, int length)
 
 -(void) stepBy: (double) h at: (double) t
 {
-    const dReal *r_H, *v_H, *omega_H, *T_BH;
+    const dReal *r_H, *v_H, *omega_H;
     dVector3 uvw, pqr;
     
     double rho;
@@ -303,7 +303,6 @@ static double lookup (double x, double *values, int length)
 
     /* State. */
     
-    T_BH = dBodyGetRotation(self->body);
     r_H = dBodyGetPosition(self->body);
     v_H = dBodyGetLinearVel(self->body);
     omega_H = dBodyGetAngularVel(self->body);
