@@ -49,7 +49,7 @@
 
     if (pass == 2) {
 	id child;
-	double M[16], P[16], w[3], q[3], p[3];
+	double M[16], P[16], w[3], q[3];
 	double I[9] = {1, 0, 0,  0, 1, 0,  0, 0, 1};
 	int v[4];
 
