@@ -18,9 +18,9 @@
 #define _ARRAY_H_
 
 #include <lua.h>
-#include "node.h"
+#include "transform.h"
 
-@interface Array: Node {
+@interface Array: Transform {
     int size, mold, spawn;
 }
 
