@@ -26,28 +26,20 @@
 
 -(Joint *) init
 {
-    [super init];
-
     self->joint = dJointCreateFixed (_WORLD, NULL);
 
+    [super init];
+
     return self;
 }
 
--(void) set
+-(void) update
 {
-    const char *k;
+    [super update];
 
-    k = lua_tostring (_L, -2);
-    
-    [super set];
-
-    if (!xstrcmp(k, "bodies")) {
-	[super set];
-
-	/* Fasten the clamp. */
+    /* Fasten the clamp. */
 	
-	dJointSetFixed ([self joint]);
-    }
+    dJointSetFixed ([self joint]);
 }
 
 @end
