@@ -21,7 +21,7 @@
 #include "gauge.h"
 
 @interface Clock: Gauge {
-    float radius[2];
+    id hands, markings;
 }
 
 @end
