@@ -581,7 +581,7 @@ int constructconvex(lua_State *L)
     id object;
     dReal *planes = NULL, *points = NULL;
     unsigned int *polygons = NULL;
-    int i, j, n = 0, m = 0, size[2];
+    int i, j, n = 0, m = 0, size[2] = {0, 0};
 
     lua_pushstring(L, "size");
     lua_gettable(L, 1);
