@@ -21,11 +21,11 @@
 #include "widget.h"
 
 @interface Frame: Widget {
-    float thickness, radius;
+    double thickness, radius;
 }
 
--(float)thickness;
--(float)radius;
+-(double)thickness;
+-(double)radius;
 
 @end
 
