@@ -22,7 +22,7 @@
 
 @interface Gauge: Widget {
     int range[2], spacing[2], size;
-    double radius[2], spread[2], thickness, background[4], *reading;
+    double radius[2], spread[2], thickness, *reading;
 }
 
 @end
