@@ -17,9 +17,9 @@
 #ifndef _HOOKE_H_
 #define _HOOKE_H_
 
-#include "node.h"
+#include "transform.h"
 
-@interface Hooke: Node {
+@interface Hooke: Transform {
     double stiffness, damping, length;
 }
 @end
