@@ -22,8 +22,10 @@
 
 @interface Item: Object {
     Item *left, *right, *up, *down;
-
     char *key;
+
+    char **properties;
+    int bloat;
 }
 
 -(id) parent;
@@ -32,6 +34,9 @@
 -(id) sister;
 -(id) root;
 -(char *) key;
+-(int) bloat;
+-(char **) properties;
+-(void) add: (int) n Properties: (char*[]) list;
 -(void) adoptedBy: (Item *) parent;
 -(void) adopt: (Item *)child named: (const char *)key;
 -(void) renounce: (Item *)child;
