@@ -22,30 +22,19 @@
 #include "item.h"
 
 @interface Node: Item {
-    Node *next;
-    
-    int linked;
-    int link, unlink, prepare, transform, step, traverse, cleanup;
-   
-    GLfloat position[3], orientation[9];
-    GLfloat translation[3], rotation[9], homogenous[16];
+    int linked, tag;
+    int link, unlink, input, prepare, step, traverse, finish, begin;
 }
 
 -(int) linked;
--(void) setPositionTo: (GLfloat *)new;
--(void) setOrientationTo: (GLfloat *)new;
--(GLfloat *) position;
--(GLfloat *) orientation;
--(GLfloat *) translation;
--(GLfloat *) rotation;
--(GLfloat *) homogenous;
 
--(void) stepBy: (double)h;
+-(void) stepBy: (double)h at: (double) t;
 -(void) toggle;
--(void) transform;
+-(void) begin;
+-(void) input;
 -(void) prepare;
 -(void) traversePass: (int)pass;
--(void) cleanup;
+-(void) finish;
 -(void) get;
 -(void) set;
 
