@@ -17,9 +17,9 @@
 #ifndef _SHAPE_H_
 #define _SHAPE_H_
 
-#include "node.h"
+#include "transform.h"
 
-@interface Shape: Node {
+@interface Shape: Transform {
     GLfloat width, color[4];
     GLfloat *vertices;
     int size;
