@@ -18,9 +18,9 @@
 #define _STALKER_H_
 
 #include <lua.h>
-#include "node.h"
+#include "transform.h"
 
-@interface Stalker: Node {
+@interface Stalker: Transform {
     id target;
     int reference;
 }
