@@ -19,9 +19,9 @@
 
 #include <lua.h>
 #include <ode/ode.h>
-#include "node.h"
+#include "transform.h"
 
-@interface Thruster: Node {
+@interface Thruster: Transform {
     dReal thrust;
 }
 
