@@ -22,10 +22,12 @@
 #include "node.h"
 
 @interface Transition: Node {
-    struct timespec start;
+    struct timespec start, last;
 
-    double duration, delta;
+    double duration, progress, speed;
     GLuint texture;
+
+    int set;
 }
 @end
 
